﻿using C1.WPF.Core;
using C1.WPF.TreeView;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace TreeViewOnDemandLoad.LazyLoad
{
    public abstract class C1TreeViewLazyLoadProvider
    {
        private Dictionary<C1TreeViewItem, object> _lazyLoadInfo;

        public C1TreeViewLazyLoadProvider()
        {
            _lazyLoadInfo = new();
        }

        /// <summary>
        /// Loads TreeViewItem's children on demand.
        /// </summary>
        /// <param name="parent">
        /// Item whose children will be loaded on demand.
        /// </param>
        /// <param name="data">
        /// Information used for lazy loading.
        /// </param>
        public void LoadOnDemand(C1TreeViewItem parent, object data)
        {
            /// Hook up event handler for lazy loading support.
            parent.Expanding += OnParentNodeExpanding;
            /// Stores the information to be used for lazy loading.
            _lazyLoadInfo[parent] = data;
        }

        private async void OnParentNodeExpanding(object? sender, SourcedEventArgs e)
        {
            var parent = sender as C1TreeViewItem;
            /// Unhook event handler after items are loaded.
            parent.Expanding -= OnParentNodeExpanding;
            await OnRequestingData(parent, _lazyLoadInfo[parent]); 
        }

        /// <summary>
        /// Provides lazy loading logic for the TreeViewItem.
        /// </summary>
        /// <param name="parent"></param>
        /// <param name="data"></param>
        /// <returns></returns>
        protected abstract Task OnRequestingData(C1TreeViewItem parent, object data);
    }
}
