﻿using C1.WPF.Core;
using C1.WPF.TreeView;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Media;
using TreeViewOnDemandLoad.ViewModel;

namespace TreeViewOnDemandLoad.LazyLoad
{
    public class ControlsLazyLoader : C1TreeViewLazyLoadProvider
    {
        private C1ProductsViewModel _viewModel;
        private C1ActivityIndicator _loadIndicator;

        public ControlsLazyLoader(C1ProductsViewModel viewModel, C1ActivityIndicator loadIndicator)
        {
            _viewModel = viewModel;
            _loadIndicator = loadIndicator;
        }

        protected override async Task OnRequestingData(C1TreeViewItem parent, object data)
        {
            _loadIndicator.Visibility = Visibility.Visible;
            var platformId = (string)data;
            await Task.Delay(1000); // Simulate Delay
            // Gets the data from data source
            var controls = await _viewModel.GetControls(platformId);
            // Remove any dummy item
            parent.Items.Clear();
            // Set controls collection as ItemsSource
            parent.ItemsSource = controls;
            parent.Foreground = Brushes.Black;
            _loadIndicator.Visibility = Visibility.Collapsed;
        }
    }
}
