﻿using C1.WPF.Core;
using C1.WPF.TreeView;
using System;
using System.Collections.Generic;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Media;
using TreeViewOnDemandLoad.LazyLoad;
using TreeViewOnDemandLoad.Model;
using TreeViewOnDemandLoad.Resources;
using TreeViewOnDemandLoad.ViewModel;

namespace TreeViewOnDemandLoad
{
    /// <summary>
    /// Interaction logic for OnDemandView.xaml
    /// </summary>
    public partial class OnDemandView : UserControl
    {
        private C1ProductsViewModel _viewModel;
        private ControlsLazyLoader _controlsLoader;

        public OnDemandView()
        {
            InitializeComponent();
            _viewModel = new C1ProductsViewModel();
            _controlsLoader = new ControlsLazyLoader(_viewModel, _loadIndicator);          
            LoadData();
        }

        #region Loading Platforms
        private void LoadData()
        {
            _viewModel.LoadData();
            var platforms = _viewModel.GetPlatforms();
            treeView.Items.Clear();

            // Creating root node
            var rootNode = new C1TreeViewItem()
            {
                IsExpanded = true,
                FontSize = 16
            };
            
            // Creating header with icon
            rootNode.Header = new IconItemView(AppResources.ComponentOne, 
                string.Format(AppResources.ImageFormat, nameof(AppResources.ComponentOne)));

            treeView.Items.Add(rootNode);

            foreach (var platform in platforms)
            {
                // Adding platforms to root node
                rootNode.Items.Add(CreatePlatformNode(platform));
            }
        }

        private C1TreeViewItem CreatePlatformNode(Platform platform)
        {
            var node = new C1TreeViewItem()
            {
                Margin = new Thickness(20, 0, 0, 0),
                IsExpanded = false,
                Foreground = Brushes.Gray
            };

            // Add a dummy node so this node can be expanded
            node.Items.Add(new C1TreeViewItem());
            node.Header = new TextBlock() { Text = platform.Name, Padding = new Thickness(10) };
            // setting item template for children
            node.ItemTemplate = treeView.ItemTemplate;
            // Loads children on demand
            _controlsLoader.LoadOnDemand(node, platform.Id);
            return node;
        }
        #endregion
    }   
}