﻿using Newtonsoft.Json;
using System.Collections.Generic;
using System.Data;
using System.IO;
using System.Linq;
using System.Threading.Tasks;
using TreeViewOnDemandLoad.Model;
using TreeViewOnDemandLoad.Resources;

namespace TreeViewOnDemandLoad.ViewModel
{
    public class C1ProductsViewModel
    {
        private IQueryable<Platform> _c1Platforms;

        /// <summary>
        /// Loads ComponentOne controls data.
        /// </summary>
        public void LoadData()
        {
            _c1Platforms = JsonConvert.DeserializeObject<List<Platform>>(File.ReadAllText("Data\\Products.json"))
                    .AsQueryable();
        }

        /// <summary>
        /// Gets supported platforms for ComponenentOne.
        /// </summary>
        /// <param name="productId"></param>
        /// <returns></returns>
        public IEnumerable<Platform> GetPlatforms()
        {
            return _c1Platforms.Select(x => new Platform()
            {
                Id = x.Id,
                Name = x.Name
            });
        }

        /// <summary>
        /// Gets available ComponentOne controls for the specified platform.
        /// </summary>
        /// <param name="productId"></param>
        /// <returns></returns>
        public async Task<IEnumerable<Control>> GetControls(string platformId)
        {
            var platform = _c1Platforms.FirstOrDefault(x => x.Id == platformId);
            return platform.Controls;
        }
    }
}
